/* Generated file (by src-generator) */

/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2015 William Yu <williamyu@gnome.org>
 *
 * This library is free software: you can redistribute it and/or modify it
 * under the terms of version 2.1. of the GNU Lesser General Public License
 * as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#if !defined (__LIBICAL_GLIB_H_INSIDE__) && !defined (LIBICAL_GLIB_COMPILATION)
#error "Only <libical-glib/libical-glib.h> can be included directly."
#endif

#ifndef I_CAL_REQSTAT_TYPE_H
#define I_CAL_REQSTAT_TYPE_H

#include <libical-glib/i-cal-object.h>
#include <libical-glib/i-cal-enums.h>

G_BEGIN_DECLS

#define I_CAL_REQSTAT_TYPE_TYPE \
        (i_cal_reqstat_type_get_type ())
#define I_CAL_REQSTAT_TYPE(obj) \
        (G_TYPE_CHECK_INSTANCE_CAST \
        ((obj), I_CAL_REQSTAT_TYPE_TYPE, ICalReqstatType))
#define I_CAL_REQSTAT_TYPE_CLASS(klass) \
        (G_TYPE_CHECK_CLASS_CAST \
        ((klass), I_CAL_REQSTAT_TYPE_TYPE, ICalReqstatTypeClass))
#define I_CAL_IS_REQSTAT_TYPE(obj) \
        (G_TYPE_CHECK_INSTANCE_TYPE \
        ((obj), I_CAL_REQSTAT_TYPE_TYPE))
#define I_CAL_IS_REQSTAT_TYPE_CLASS(klass) \
        (G_TYPE_CHECK_CLASS_TYPE \
        ((klass), I_CAL_REQSTAT_TYPE_TYPE))

/**
 * ICalReqstatType:
 *
 * This is the ICalReqstatType instance.
 */
typedef struct _ICalReqstatType ICalReqstatType;

/**
 * ICalReqstatTypeClass:
 *
 * This is the ICalReqstatType class.
 */
typedef struct _ICalReqstatTypeClass ICalReqstatTypeClass;

struct _ICalReqstatType {
	/*< private >*/
	ICalObject parent;
};

struct _ICalReqstatTypeClass {
	/*< private >*/
	ICalObjectClass parent;
};

GType 		i_cal_reqstat_type_get_type	(void);
ICalReqstatType *
		i_cal_reqstat_type_from_string	(const gchar *str);
gchar *		i_cal_reqstat_type_as_string_r	(ICalReqstatType *stat);
ICalRequestStatus 
		i_cal_reqstat_type_get_code	(ICalReqstatType *reqstat);
void		i_cal_reqstat_type_set_code	(ICalReqstatType *reqstat,
						 ICalRequestStatus code);
const gchar *	i_cal_reqstat_type_get_desc	(ICalReqstatType *reqstat);
const gchar *	i_cal_reqstat_type_get_debug	(ICalReqstatType *reqstat);

G_END_DECLS

#endif /* I_CAL_REQSTAT_TYPE_H */
